==> tensorflow_recommenders_addons-0.4.0-cp39-cp39-macosx_12_0_arm64.whl: tensorflow_recommenders_addons/version.py <==
# Copyright 2020 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ============================================================================
"""Define TensorFlow Recommenders Addons version information."""

import os

# Required TensorFlow version [min, max)
MIN_TF_VERSION = os.getenv("TF_VERSION", "2.5.0")
MAX_TF_VERSION = os.getenv("TF_VERSION", "2.7.0")

# We follow Semantic Versioning (https://semver.org/)
_MAJOR_VERSION = "0"
_MINOR_VERSION = "4"
_PATCH_VERSION = "0"

# When building releases, we can update this value on the release branch to
# reflect the current release candidate ('rc0', 'rc1') or, finally, the official
# stable release (indicated by `_VERSION_SUFFIX = ''`). Outside the context of a
# release branch, the current version is by default assumed to be a
# 'development' version, labeled 'dev'.
_VERSION_SUFFIX = ""

# Example, '0.1.0-dev'
__version__ = ".".join([_MAJOR_VERSION, _MINOR_VERSION, _PATCH_VERSION])
if _VERSION_SUFFIX:
  __version__ = "{}-{}".format(__version__, _VERSION_SUFFIX)

==> tensorflow_recommenders_addons-0.5.0-cp39-cp39-macosx_12_0_arm64.whl: tensorflow_recommenders_addons/version.py <==
# Copyright 2020 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ============================================================================
"""Define TensorFlow Recommenders Addons version information."""

import os
import platform


def is_macos():
  return platform.system() == "Darwin"


def is_arm64():
  return platform.machine() == "arm64"


# Required TensorFlow version [min, max)
if (is_macos() and is_arm64()):
  MIN_TF_VERSION = os.getenv("TF_VERSION", "2.6.0")
  MAX_TF_VERSION = os.getenv("TF_VERSION", "2.8.0")
else:
  MIN_TF_VERSION = os.getenv("TF_VERSION", "2.6.3")
  MAX_TF_VERSION = os.getenv("TF_VERSION", "2.8.3")

# We follow Semantic Versioning (https://semver.org/)
_MAJOR_VERSION = "0"
_MINOR_VERSION = "5"
_PATCH_VERSION = "0"

# When building releases, we can update this value on the release branch to
# reflect the current release candidate ('rc0', 'rc1') or, finally, the official
# stable release (indicated by `_VERSION_SUFFIX = ''`). Outside the context of a
# release branch, the current version is by default assumed to be a
# 'development' version, labeled 'dev'.
_VERSION_SUFFIX = "dev"

# Example, '0.1.0-dev'
__version__ = ".".join([_MAJOR_VERSION, _MINOR_VERSION, _PATCH_VERSION])
# if _VERSION_SUFFIX:
#   __version__ = "{}-{}".format(__version__, _VERSION_SUFFIX)
